@@ -27,6 +27,8 @@ def convertToImage(src, dst):
         img.save(dstPath)
     print('Files converted successfully')
     
+# trainPath = directory containing the train set. valid_pct = Percent of data used for validation set. bs = batch size. get_items = Function used extract the train set. get_p = Function used to classify the train set. item_tfms = Transforms to be performed on all of the data. batch_tfms = Transforms to be performed on each batch.
+# Returns a dataloader object
 def loadData(trainPath, valid_pct, bs=None, get_items=get_image_files, get_y = parent_label, item_tfms = Resize(224, ResizeMethod.Pad, pad_mode='zeros'), batch_tfms = aug_transforms()):
     #aug_transforms(pad_mode='zeros', mult=2, min_scale=0.5)
     # parent_label -->> simply gets the name of the folder a file is in
@@ -42,9 +44,10 @@ def loadData(trainPath, valid_pct, bs=None, get_items=get_image_files, get_y = p
     return dls
 
 # dls = DataLoaders object, arch = architecture, path = path to where the trained model should be exported, epoch_ct = number of iterations, metrics = the metrics used to train the model, pretrained = whether or not to use a pretrained model (False = Create model from scratch)
-def trainModel(dls, arch, path, epoch_ct=1, metrics=error_rate, pretrained=True):
+def trainModel(dls, arch, path, epoch_ct=1, base_lr=None metrics=error_rate, pretrained=True):
     model = cnn_learner(dls, arch, metrics=metrics, pretrained=pretrained)
-    model.fine_tune(epochs=epoch_ct)
+    #print(model.lr_find())
+    model.fine_tune(epochs=epoch_ct, base_lr = base_lr)
     model.dls.train = dls.train
     model.dls.valid = dls.valid
     model.export(path)
@@ -55,14 +58,6 @@ def loadModel(exportPath, cpu=False):
     model = load_learner(exportPath, cpu)
     return model
 
-# directory = path you want to check whether it is a directory or file
-# Returns True if it is a directory, False if it is not.
-def isDir(directory):
-    isDir = os.path.isdir(directory)
-    if isDir == False:
-        print("Error: Directory not found, please try again")
-    return isDir
-    
 # item = the specific image you want to show
 def showImages(item):
     # Show the images that are being predicted
